@@ -34,20 +34,26 @@
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
 #![deny(clippy::unwrap_used)]
+#![deny(clippy::mod_module_files)]
 #![allow(clippy::let_unit_value)] // This can reasonably be done for explicitness
 #![allow(clippy::uninlined_format_args)]
 #![allow(clippy::significant_drop_in_scrutinee)] // arti/-/merge_requests/588/#note_2812945
 #![allow(clippy::result_large_err)] // temporary workaround for arti#587
 #![allow(clippy::needless_raw_string_hashes)] // complained-about code is fine, often best
+#![allow(clippy::needless_lifetimes)] // See arti#1765
+#![allow(mismatched_lifetime_syntaxes)] // temporary workaround for arti#2060
 //! <!-- @@ end lint list maintained by maint/add_warning @@ -->
 
 pub mod cmdline;
 mod err;
+#[macro_use]
+pub mod extend_builder;
 pub mod file_watcher;
 mod flatten;
 pub mod list_builder;
 mod listen;
 pub mod load;
+pub mod map_builder;
 mod misc;
 pub mod mistrust;
 mod mut_cfg;
@@ -75,7 +81,6 @@ pub use load::{resolve, resolve_ignore_warnings, resolve_return_results};
 pub use misc::*;
 pub use mut_cfg::MutCfg;
 pub use sources::{ConfigurationSource, ConfigurationSources};
-pub use tor_config_path::{CfgPath, CfgPathError};
 
 use itertools::Itertools;
 
@@ -101,7 +106,7 @@ impl ConfigurationTree {
         use figment::value::Value as V;
         let val = self.0.find_value(key).map_err(ConfigError::from_cfg_err)?;
         Ok(match val {
-            V::String(_, s) => s.to_string(),
+            V::String(_, s) => s.clone(),
             V::Num(_, n) => n.to_i128().expect("Failed to extract i128").to_string(),
             _ => format!("{:?}", val),
         })
